/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0} är {1}. av {2}"

, "Recurrances"
: "Recurrances"

, "No recurring rule defined"
: "Ingen återkommande regel definieras"

, "Details"
: "Detaljer"

, "None"
: "Ingen"

, "Daily"
: "Dagligen"

, "Weekly"
: "Veckovis"

, "Monthly"
: "Månadsvis"

, "Yearly"
: "Årligen"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Undantag för återfallna händelser kan inte ha återfall själva."

, "at"
: "vid"

, "never"
: "aldrig"

, "after {0} occurrences"
: "efter {0} händelser"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Slut"

, "Until has to be after event start"
: "Tills måste vara efter händelse start"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Varje {0}. dag"

, "Every {0}. Week at"
: "Varje {0}. vecka"

, "Every {0}. Month"
: "Varje {0}. månad"

, "at the"
: "vid"

, "first"
: "först"

, "second"
: "andra"

, "third"
: "tredje"

, "fourth"
: "fjärde"

, "last"
: "sista"

, "Every {0}. Year"
: "Varje {0}. år"

, "of"
: "av"

, "Summary"
: "Sammanfattning"

, "Organizer"
: "Organiserare"

, "Description"
: "Beskrivning"

, "Location"
: "Plats"

, "Start Time"
: "Starttid"

, "End Time"
: "Sluttid"

, "Attendee"
: "Deltagare"

, "whole day"
: "hela dagen"

, "Week {0} :"
: "Vecka {0} :"

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Ny händelse"

, "Calendar, Calendars"
: [
  "Kalender"
 ,"Kalendrar"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: ""

, "Sort Attendee"
: ""

, "Check to filter for this attendee"
: ""

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Laddar händelser, var god vänta..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "Skriv ut sida"

, "Loose-Leaf"
: ""

, "Sheet"
: "Ark"

, "Grid"
: "Grid"

, "Timeline"
: ""

, "Day"
: "Dag"

, "Week"
: "Vecka"

, "Month"
: "Månad"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Ställ mitt svar"

, "Copy {0}"
: "Kopiera {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Uppdatera händelser i det förflutna"

, "Update this event"
: "Uppdatera denna händelsen"

, "Do not update this event"
: "Uppdatera inte denna händelsen"

, "Creating event in the past"
: "Skapa händelse i det förflutna"

, "Create this event"
: "Skapa denna händelse"

, "Do not create this event"
: "Skapa inte denna händelse"

, "Update this event only"
: "Uppdatera endast denna händelsen"

, "Update this and all future events"
: "Uppdatera denna händelsen och alla framtida händelser"

, "Update whole series"
: "Uppdatera hela serier"

, "Update nothing"
: "Uppdatera ingeting"

, "Update Event"
: "Uppdatera händelse"

, "Please Change Selection"
: "Var god byt val"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Ditt val innehåller återkommande händelser. Återkommande händelser måste tas bort separat"

, "Delete Event"
: "Radera Händelser"

, "Delete this event only"
: "Radera endast denna händelse"

, "Delete this and all future events"
: "Radera denna och alla framtida händelser"

, "Delete whole series"
: "Radera hela serier"

, "Delete nothing"
: "Radera inget"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Vill du verkligen radera denna händelse?"
 ,"Vill du verkligen radera  {0} valda händelser?"

]
, "Could not Print"
: "Kunde inte Skriva ut"

, "Sorry, your current view does not support printing."
: "Ledsen, ditt för nuvarande visning stödjer inte utskrivning"

, "Scheduling Conflict"
: "Schemalägg Konflikt"

, "The following attendee are busy at the requested time:"
: "Följande deltagare är upptagna på den begärda tiden:"

, "Ignore Conflict"
: "Ignorera Konflikt"

, "Edit Event"
: "Ända Händelse"

, "Cancel this action"
: "Avbryt denna åtgärd"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Hantera resurser"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Välj deltagare"

, "Attachments"
: ""

, "Private"
: "Privat"

, "Tags"
: "Taggar"

, "Blocking"
: "blockerande"

, "Tentative"
: "Preliminärt"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "privat klassificering"

, "recurring event"
: "återkommande händelse"

, "recurring event exception"
: "återkommande händelse undantag"

, "has alarm"
: "har larm"

, "has attachments"
: ""

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Mini Kalender"

, "WK"
: "WK"

, "{0} more..."
: "{0} mer..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Vänligen välj en händelse att lägga till kontakterna på"

, "Role"
: "Roll"

, "Select Role"
: "Välj roll"

, "Status"
: "Status"

, "Select Status"
: "Välj status"

, "Adding {0} Attendee to event"
: "Lägger till {0} deltagare till händelsen"

, "no events found"
: "inga händelser funna"

, "Searching..."
: "Söker..."

, "Search Event"
: "Sök Händelse"

, "Event, Events"
: [
  "Händelse"
 ,"Händelser"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "icke-blockerande"

, "Displayed in"
: ""

, "No Information"
: "Ingen information"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Händelse"

, "Calendars"
: "Kalendrar"

, "Quick Search"
: ""

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "deltagar Status"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Deltagar-roll"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Klassificering"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: "Klockan {0} {1}"

, "Event (as attendee)"
: "Händelse (som deltagare)"

, "Event (as organizer)"
: "Händelse (som organiserare)"

, "Event attendee"
: "Händelse deltagare"

, "Attender, Attendee"
: [
  "Deltagare"
 ,"Deltagare"

]
, "Resource, Resources"
: [
  "Resurs"
 ,"Resurser"

]
, "Resources"
: "Resurser"

, "Anyone"
: ""

, "Name"
: "Namn"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Email"

, "Maximum number of attendee"
: ""

, "Type"
: "Typ"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Klicka här för att bjuda in ytterligare deltagare"

, "User"
: "Användare"

, "Group"
: "Grupp"

, "Member of group"
: "Medlem i grupp"

, "This is the calendar where the attender has saved this event in"
: "Detta är den kalender som deltagaren har sparat händelsen i"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Ta bort deltagare"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(som gruppmedlem)"

, "External Attendee"
: ""

, "Originally"
: "Ursprungligen"

, "Checking Calendar Data..."
: "Kontrollerar kalenderdata..."

, "Reply to Recurring Event"
: "Svara på återkommande händelse"

, "You are responding to an recurring event. What would you like to do?"
: "Du svarar på ett återkommande evenemang. Vad vill du göra?"

, "Respond to whole series"
: "Svara på hela serien"

, "Do not respond"
: "Svara inte"

, "The event of this message does not exist"
: "Evenemanget av detta meddelande finns inte"

, "The sender is not authorised to update the event"
: "Avsändaren är inte tillåten att uppdatera evenemanget"

, "This message is already processed"
: "Detta meddelande är redan behandlat"

, "You are not an attendee of this event"
: "Du är inte en deltagare av denna händelse"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "Icke godkännt meddelande"

, "This is an event invitation for someone else."
: "Detta är en händelse inbjudan till någon annan."

, "You have already replied to this event invitation."
: "Du har redan svarat på den här händelsen inbjudan."

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Du har fått en händelse inbjudan. Ställ ditt svar till:"

, "An invited attendee responded to the invitation."
: "En inbjuden deltagare svarade på inbjudan."

, "Unsupported method"
: "Icke godkännd metod"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Fyll i beskrivning"

, "Grants"
: ""

, "This event is originally stored in a calendar you don't have access to."
: "Den här händelsen lagrades ursprungligen i en kalender du inte har tillgång till."

, "This event is originally stored in {0}"
: "Den här händelsen lagrades ursprungligen i {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Denna händelse visas också i din personliga kalender {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Visa"

, "Saved in"
: "Sparad i"

, "Enter description"
: "Beskrivning"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Slutdatum är ogiltigt"

, "End date must be after start date"
: "Slutdatum måste vara efter startdatum"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "Startdatum är ogiligt"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "Sammanfattningen får inte vara längre än 255 tecken."

, "The summary must have at least 1 character."
: "Sammanfattningen måste bestå av minst 1 tecken."

, "Summary too Long"
: "Sammanfattningen är för lång"

, "Summary too Short"
: "Sammanfattningen är för kort"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Alla mina event"

, "Position on the left time axis, day and week view should start with"
: "Placera på den vänstra tidsaxeln, dag och vecka vy ska börja med"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Standard kalender"

, "The default calendar for invitations and new events"
: "Standard kalendern för inbjudningar och nya händelser"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on calendar startup"
: "Standard favorit som är laddad på kalender start"

, "Get Notification Emails"
: "Få Notifierings Mail"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Nivån på åtgärder som du vill bli informerad om. Observera att arrangörerna kommer att få meddelanden för alla uppdateringar, inklusive deltagarnas svar om den här inställningen är inställd på \"Aldrig\""

, "Send Notifications Emails of own Actions"
: "Skicka Notifierings Mail av egna Åtgärder"

, "Get notifications emails for actions you did yourself"
: "Få notifierings mail för åtgärder som du skapade själv"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Aktivera standardlarm"

, "New events get a standard alarm as defined below"
: "Nya händelser får ett standardlarm som definerat nedan"

, "Standard Alarm Time"
: "Tid för standardlarm"

, "Minutes before the event starts"
: "Minuter innan händelsens början"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Korrigerade kalendrar"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Aldrig"

, "On invitation and cancellation only"
: "På inbjudan och avbokning enbart"

, "On time changes"
: "På tids ändringar"

, "On all updates but attendee responses"
: "På alla uppdateringar men deltagarens svar"

, "On attendee responses too"
: "På deltagerens svar också"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Kalendrar alltid utvalda oavsett av alla filter parametrar. En godkännd användning kan vara att tvinga visning av en viss helgdag kalender."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Deltagarstatus tillgänglig"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Inget svar"

, "Accepted"
: "Godkännt"

, "Declined"
: "Nekat"

, "Attendee Roles Available"
: "Tillgängliga deltagarroller"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Krävs"

, "Optional"
: "Valfritt"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "%s's personliga kalender"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "okänd"

, "This contact has been automatically added by the system as an event attender"
: "Denna kontakt har automatiskt lagts till av systemet som en händelse deltagare"

, "The email address has been shortened:"
: ""

, "Every %s day"
: ""

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: ""

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "Start"

, "Priority"
: "Prioritet"

, "Url"
: "Url"

, "Recurrance rule"
: "Återfalls regel"

, "Is all day event"
: "Är en heldags händelse"

, "Organizer timezone"
: "Organisera tidzoner"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Alarm för händelse \"%1$s\" vid %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Inbjudan till händelse \"%1$s\" vid %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "Händelse \"%1$s\" vid %2$s har blivit inställd"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Händelse \"%1$s\" har blivit flyttad från %2$s till %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "Händelse \"%1$s\" vid %2$s har blivit uppdaterad"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s accepterade händelsen \"%2$s\" vid %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s nekade händelsen \"%2$s\" vid %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Preliminärt svar från %1$s för evenemanget \"%2$s\" på %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Ingen respons från %1$s för händelsen \"%2$s\" vid %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Deltagarens förändringar för evenemanget \"%1$s\" på %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Uppdateringar"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s ändras från \"%2$s\" till \"%3$s\""

, "%1$s has been invited"
: "%1$s har inbjudits"

, "%1$s has been removed"
: "%1$s har blivit flyttad"

, "%1$s accepted invitation"
: "%1$s godkände inbjudan"

, "%1$s declined invitation"
: "%1$s tackade nej till inbjudan"

, "Tentative response from %1$s"
: "Preliminärt svar från %1$s"

, "No response from %1$s"
: "Inget svar från %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" svar från %1$s"

, "Link"
: ""

, "Event details"
: "Händelse detaljer"

, "All events I attend"
: "Alla händelser Jag varit med på"

, "Awaiting response"
: "Avvaktar svar"

, "Events I have not yet responded to"
: "Händelser Jag inte ännu svarat på"

, "Declined events"
: "Tacka nej händelser"

, "Events I have declined"
: "Händerlser Jag tackat nej till"

, "I'm organizer"
: "Jag är arrangör"

, "Events I'm the organizer of"
: "Händelser Jag är arrangör för."

, "manage shared calendars"
: "Hantera delade kalendrar"

, "Create new shared calendars"
: "Skapa ny delad kalender"

, "manage shared calendars favorites"
: "Hantera delade favoritkalendrar"

, "Create or update shared calendars favorites"
: "Skapa eller uppdatera delade favoritkalendrar"

, "manage resources"
: "Hantera resurser"

, "All Rights to administrate resources"
: "Alla rättigheter för att administrera resurser"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Kalender"

, "Do you really want to delete this event?"
: "Vill du verkligen radera denna händelse?"

, "Resource Grant"
: ""

, "Event"
: "Händelse"

, "Attender"
: "Deltagare"

, "Resource"
: "Resurs"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
